import * as _m0 from "protobufjs/minimal";
export declare const protobufPackage = "";
/** 枚举消息类型 */
export declare enum EventType {
    /** Echo - 回响消息 */
    Echo = 0,
    /** Error - 系统错误 */
    Error = 1,
    /** Status - 系统状态 */
    Status = 2,
    /** CertList - 获取证书列表 */
    CertList = 3,
    /** CertDetail - 证书详细 */
    CertDetail = 4,
    /** EmailInfo - 邮件信息 */
    EmailInfo = 5,
    /** DisposeEmail - 处理邮件 */
    DisposeEmail = 6,
    UNRECOGNIZED = -1
}
export declare function eventTypeFromJSON(object: any): EventType;
export declare function eventTypeToJSON(object: EventType): string;
export interface CertInfo {
    /** sha1 hash */
    hash: string;
    /** 通用名称 */
    commonName: string;
    /** 电子邮件 */
    emails: string[];
    /** 颁发者 */
    issuer: string;
}
export interface EchoEvent {
    reqId: string;
    msg: string;
}
export interface ErrorEvent {
    reqId: string;
    /** 错误码 */
    code: number;
    error: string;
}
export interface StatusEventReq {
    reqId: string;
    /** sdk服务版本 */
    version: string;
}
export interface StatusEventResp {
    reqId: string;
    /** 服务器版本 */
    version: string;
}
export interface CertListEventReq {
    reqId: string;
    /** 用于加密 */
    toEncrypt: boolean;
    /** 签名邮箱 */
    toSign: string;
}
export interface CertListEventResp {
    reqId: string;
    count: number;
    certs: CertInfo[];
}
export interface CertDetailEventReq {
    reqId: string;
    /** sha1 hash */
    hash: string;
}
export interface CertDetailEventResp {
    reqId: string;
    /** 证书原始数据DER */
    raw: Uint8Array;
    /** sha1 hash */
    hash: string;
    /** 通用名称 */
    commonName: string;
}
export interface EmailInfoEventReq {
    reqId: string;
    /** 请求密文-响应明文 */
    body: Uint8Array;
    /** 当前邮箱 */
    recipient: string;
}
export interface EmailInfoEventResp {
    reqId: string;
    /** 响应明文 */
    body: Uint8Array;
    /** 是否签名 */
    signed: boolean;
    /** 是否加密 */
    encrypted: boolean;
    /** 证书信息 */
    cert: CertInfo | undefined;
    /** 验证解密错误 */
    error: string;
    /** 提示信息 */
    reason: string;
}
export interface Attachment {
    /** http:// or https:// or name */
    name: string;
    body: Uint8Array;
}
export interface DisposeEmailEventReq {
    reqId: string;
    /** 待加密签名内容 */
    body: Uint8Array;
    /** 附件或URL */
    attachments: Attachment[];
    /** 发送给，有值即加密 */
    tos: string[];
    /** 签名证书hash */
    signCert: string;
}
export interface DisposeEmailEventResp {
    reqId: string;
    /** 密文 */
    body: Uint8Array;
    /** 错误 */
    error: string;
    /** 提示信息 */
    reason: string;
}
export declare const CertInfo: {
    encode(message: CertInfo, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CertInfo;
    fromJSON(object: any): CertInfo;
    toJSON(message: CertInfo): unknown;
    create<I extends {
        hash?: string;
        commonName?: string;
        emails?: string[];
        issuer?: string;
    } & {
        hash?: string;
        commonName?: string;
        emails?: string[] & string[] & { [K in Exclude<keyof I["emails"], keyof string[]>]: never; };
        issuer?: string;
    } & { [K_1 in Exclude<keyof I, keyof CertInfo>]: never; }>(base?: I): CertInfo;
    fromPartial<I_1 extends {
        hash?: string;
        commonName?: string;
        emails?: string[];
        issuer?: string;
    } & {
        hash?: string;
        commonName?: string;
        emails?: string[] & string[] & { [K_2 in Exclude<keyof I_1["emails"], keyof string[]>]: never; };
        issuer?: string;
    } & { [K_3 in Exclude<keyof I_1, keyof CertInfo>]: never; }>(object: I_1): CertInfo;
};
export declare const EchoEvent: {
    encode(message: EchoEvent, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): EchoEvent;
    fromJSON(object: any): EchoEvent;
    toJSON(message: EchoEvent): unknown;
    create<I extends {
        reqId?: string;
        msg?: string;
    } & {
        reqId?: string;
        msg?: string;
    } & { [K in Exclude<keyof I, keyof EchoEvent>]: never; }>(base?: I): EchoEvent;
    fromPartial<I_1 extends {
        reqId?: string;
        msg?: string;
    } & {
        reqId?: string;
        msg?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof EchoEvent>]: never; }>(object: I_1): EchoEvent;
};
export declare const ErrorEvent: {
    encode(message: ErrorEvent, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ErrorEvent;
    fromJSON(object: any): ErrorEvent;
    toJSON(message: ErrorEvent): unknown;
    create<I extends {
        reqId?: string;
        code?: number;
        error?: string;
    } & {
        reqId?: string;
        code?: number;
        error?: string;
    } & { [K in Exclude<keyof I, keyof ErrorEvent>]: never; }>(base?: I): ErrorEvent;
    fromPartial<I_1 extends {
        reqId?: string;
        code?: number;
        error?: string;
    } & {
        reqId?: string;
        code?: number;
        error?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof ErrorEvent>]: never; }>(object: I_1): ErrorEvent;
};
export declare const StatusEventReq: {
    encode(message: StatusEventReq, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): StatusEventReq;
    fromJSON(object: any): StatusEventReq;
    toJSON(message: StatusEventReq): unknown;
    create<I extends {
        reqId?: string;
        version?: string;
    } & {
        reqId?: string;
        version?: string;
    } & { [K in Exclude<keyof I, keyof StatusEventReq>]: never; }>(base?: I): StatusEventReq;
    fromPartial<I_1 extends {
        reqId?: string;
        version?: string;
    } & {
        reqId?: string;
        version?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof StatusEventReq>]: never; }>(object: I_1): StatusEventReq;
};
export declare const StatusEventResp: {
    encode(message: StatusEventResp, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): StatusEventResp;
    fromJSON(object: any): StatusEventResp;
    toJSON(message: StatusEventResp): unknown;
    create<I extends {
        reqId?: string;
        version?: string;
    } & {
        reqId?: string;
        version?: string;
    } & { [K in Exclude<keyof I, keyof StatusEventResp>]: never; }>(base?: I): StatusEventResp;
    fromPartial<I_1 extends {
        reqId?: string;
        version?: string;
    } & {
        reqId?: string;
        version?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof StatusEventResp>]: never; }>(object: I_1): StatusEventResp;
};
export declare const CertListEventReq: {
    encode(message: CertListEventReq, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CertListEventReq;
    fromJSON(object: any): CertListEventReq;
    toJSON(message: CertListEventReq): unknown;
    create<I extends {
        reqId?: string;
        toEncrypt?: boolean;
        toSign?: string;
    } & {
        reqId?: string;
        toEncrypt?: boolean;
        toSign?: string;
    } & { [K in Exclude<keyof I, keyof CertListEventReq>]: never; }>(base?: I): CertListEventReq;
    fromPartial<I_1 extends {
        reqId?: string;
        toEncrypt?: boolean;
        toSign?: string;
    } & {
        reqId?: string;
        toEncrypt?: boolean;
        toSign?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof CertListEventReq>]: never; }>(object: I_1): CertListEventReq;
};
export declare const CertListEventResp: {
    encode(message: CertListEventResp, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CertListEventResp;
    fromJSON(object: any): CertListEventResp;
    toJSON(message: CertListEventResp): unknown;
    create<I extends {
        reqId?: string;
        count?: number;
        certs?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        }[];
    } & {
        reqId?: string;
        count?: number;
        certs?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        }[] & ({
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        } & {
            hash?: string;
            commonName?: string;
            emails?: string[] & string[] & { [K in Exclude<keyof I["certs"][number]["emails"], keyof string[]>]: never; };
            issuer?: string;
        } & { [K_1 in Exclude<keyof I["certs"][number], keyof CertInfo>]: never; })[] & { [K_2 in Exclude<keyof I["certs"], keyof {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        }[]>]: never; };
    } & { [K_3 in Exclude<keyof I, keyof CertListEventResp>]: never; }>(base?: I): CertListEventResp;
    fromPartial<I_1 extends {
        reqId?: string;
        count?: number;
        certs?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        }[];
    } & {
        reqId?: string;
        count?: number;
        certs?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        }[] & ({
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        } & {
            hash?: string;
            commonName?: string;
            emails?: string[] & string[] & { [K_4 in Exclude<keyof I_1["certs"][number]["emails"], keyof string[]>]: never; };
            issuer?: string;
        } & { [K_5 in Exclude<keyof I_1["certs"][number], keyof CertInfo>]: never; })[] & { [K_6 in Exclude<keyof I_1["certs"], keyof {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        }[]>]: never; };
    } & { [K_7 in Exclude<keyof I_1, keyof CertListEventResp>]: never; }>(object: I_1): CertListEventResp;
};
export declare const CertDetailEventReq: {
    encode(message: CertDetailEventReq, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CertDetailEventReq;
    fromJSON(object: any): CertDetailEventReq;
    toJSON(message: CertDetailEventReq): unknown;
    create<I extends {
        reqId?: string;
        hash?: string;
    } & {
        reqId?: string;
        hash?: string;
    } & { [K in Exclude<keyof I, keyof CertDetailEventReq>]: never; }>(base?: I): CertDetailEventReq;
    fromPartial<I_1 extends {
        reqId?: string;
        hash?: string;
    } & {
        reqId?: string;
        hash?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof CertDetailEventReq>]: never; }>(object: I_1): CertDetailEventReq;
};
export declare const CertDetailEventResp: {
    encode(message: CertDetailEventResp, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CertDetailEventResp;
    fromJSON(object: any): CertDetailEventResp;
    toJSON(message: CertDetailEventResp): unknown;
    create<I extends {
        reqId?: string;
        raw?: Uint8Array;
        hash?: string;
        commonName?: string;
    } & {
        reqId?: string;
        raw?: Uint8Array;
        hash?: string;
        commonName?: string;
    } & { [K in Exclude<keyof I, keyof CertDetailEventResp>]: never; }>(base?: I): CertDetailEventResp;
    fromPartial<I_1 extends {
        reqId?: string;
        raw?: Uint8Array;
        hash?: string;
        commonName?: string;
    } & {
        reqId?: string;
        raw?: Uint8Array;
        hash?: string;
        commonName?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof CertDetailEventResp>]: never; }>(object: I_1): CertDetailEventResp;
};
export declare const EmailInfoEventReq: {
    encode(message: EmailInfoEventReq, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): EmailInfoEventReq;
    fromJSON(object: any): EmailInfoEventReq;
    toJSON(message: EmailInfoEventReq): unknown;
    create<I extends {
        reqId?: string;
        body?: Uint8Array;
        recipient?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        recipient?: string;
    } & { [K in Exclude<keyof I, keyof EmailInfoEventReq>]: never; }>(base?: I): EmailInfoEventReq;
    fromPartial<I_1 extends {
        reqId?: string;
        body?: Uint8Array;
        recipient?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        recipient?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof EmailInfoEventReq>]: never; }>(object: I_1): EmailInfoEventReq;
};
export declare const EmailInfoEventResp: {
    encode(message: EmailInfoEventResp, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): EmailInfoEventResp;
    fromJSON(object: any): EmailInfoEventResp;
    toJSON(message: EmailInfoEventResp): unknown;
    create<I extends {
        reqId?: string;
        body?: Uint8Array;
        signed?: boolean;
        encrypted?: boolean;
        cert?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        };
        error?: string;
        reason?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        signed?: boolean;
        encrypted?: boolean;
        cert?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        } & {
            hash?: string;
            commonName?: string;
            emails?: string[] & string[] & { [K in Exclude<keyof I["cert"]["emails"], keyof string[]>]: never; };
            issuer?: string;
        } & { [K_1 in Exclude<keyof I["cert"], keyof CertInfo>]: never; };
        error?: string;
        reason?: string;
    } & { [K_2 in Exclude<keyof I, keyof EmailInfoEventResp>]: never; }>(base?: I): EmailInfoEventResp;
    fromPartial<I_1 extends {
        reqId?: string;
        body?: Uint8Array;
        signed?: boolean;
        encrypted?: boolean;
        cert?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        };
        error?: string;
        reason?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        signed?: boolean;
        encrypted?: boolean;
        cert?: {
            hash?: string;
            commonName?: string;
            emails?: string[];
            issuer?: string;
        } & {
            hash?: string;
            commonName?: string;
            emails?: string[] & string[] & { [K_3 in Exclude<keyof I_1["cert"]["emails"], keyof string[]>]: never; };
            issuer?: string;
        } & { [K_4 in Exclude<keyof I_1["cert"], keyof CertInfo>]: never; };
        error?: string;
        reason?: string;
    } & { [K_5 in Exclude<keyof I_1, keyof EmailInfoEventResp>]: never; }>(object: I_1): EmailInfoEventResp;
};
export declare const Attachment: {
    encode(message: Attachment, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Attachment;
    fromJSON(object: any): Attachment;
    toJSON(message: Attachment): unknown;
    create<I extends {
        name?: string;
        body?: Uint8Array;
    } & {
        name?: string;
        body?: Uint8Array;
    } & { [K in Exclude<keyof I, keyof Attachment>]: never; }>(base?: I): Attachment;
    fromPartial<I_1 extends {
        name?: string;
        body?: Uint8Array;
    } & {
        name?: string;
        body?: Uint8Array;
    } & { [K_1 in Exclude<keyof I_1, keyof Attachment>]: never; }>(object: I_1): Attachment;
};
export declare const DisposeEmailEventReq: {
    encode(message: DisposeEmailEventReq, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DisposeEmailEventReq;
    fromJSON(object: any): DisposeEmailEventReq;
    toJSON(message: DisposeEmailEventReq): unknown;
    create<I extends {
        reqId?: string;
        body?: Uint8Array;
        attachments?: {
            name?: string;
            body?: Uint8Array;
        }[];
        tos?: string[];
        signCert?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        attachments?: {
            name?: string;
            body?: Uint8Array;
        }[] & ({
            name?: string;
            body?: Uint8Array;
        } & {
            name?: string;
            body?: Uint8Array;
        } & { [K in Exclude<keyof I["attachments"][number], keyof Attachment>]: never; })[] & { [K_1 in Exclude<keyof I["attachments"], keyof {
            name?: string;
            body?: Uint8Array;
        }[]>]: never; };
        tos?: string[] & string[] & { [K_2 in Exclude<keyof I["tos"], keyof string[]>]: never; };
        signCert?: string;
    } & { [K_3 in Exclude<keyof I, keyof DisposeEmailEventReq>]: never; }>(base?: I): DisposeEmailEventReq;
    fromPartial<I_1 extends {
        reqId?: string;
        body?: Uint8Array;
        attachments?: {
            name?: string;
            body?: Uint8Array;
        }[];
        tos?: string[];
        signCert?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        attachments?: {
            name?: string;
            body?: Uint8Array;
        }[] & ({
            name?: string;
            body?: Uint8Array;
        } & {
            name?: string;
            body?: Uint8Array;
        } & { [K_4 in Exclude<keyof I_1["attachments"][number], keyof Attachment>]: never; })[] & { [K_5 in Exclude<keyof I_1["attachments"], keyof {
            name?: string;
            body?: Uint8Array;
        }[]>]: never; };
        tos?: string[] & string[] & { [K_6 in Exclude<keyof I_1["tos"], keyof string[]>]: never; };
        signCert?: string;
    } & { [K_7 in Exclude<keyof I_1, keyof DisposeEmailEventReq>]: never; }>(object: I_1): DisposeEmailEventReq;
};
export declare const DisposeEmailEventResp: {
    encode(message: DisposeEmailEventResp, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DisposeEmailEventResp;
    fromJSON(object: any): DisposeEmailEventResp;
    toJSON(message: DisposeEmailEventResp): unknown;
    create<I extends {
        reqId?: string;
        body?: Uint8Array;
        error?: string;
        reason?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        error?: string;
        reason?: string;
    } & { [K in Exclude<keyof I, keyof DisposeEmailEventResp>]: never; }>(base?: I): DisposeEmailEventResp;
    fromPartial<I_1 extends {
        reqId?: string;
        body?: Uint8Array;
        error?: string;
        reason?: string;
    } & {
        reqId?: string;
        body?: Uint8Array;
        error?: string;
        reason?: string;
    } & { [K_1 in Exclude<keyof I_1, keyof DisposeEmailEventResp>]: never; }>(object: I_1): DisposeEmailEventResp;
};
declare type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export declare type DeepPartial<T> = T extends Builtin ? T : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
declare type KeysOfUnion<T> = T extends T ? keyof T : never;
export declare type Exact<P, I extends P> = P extends Builtin ? P : P & {
    [K in keyof P]: Exact<P[K], I[K]>;
} & {
    [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
};
export {};
